=======
Credits
=======

Development Lead
----------------

* Ben Lopatin <ben@wellfire.co>

Contributors
------------

* `snake-plissken <https://github.com/snake-plissken>`_
* `Eric Theise <https://github.com/erictheise>`_
